==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/AccessLoggingFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface AccessLoggingFluent<A extends io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildDestination instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestination getDestination();
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestination buildDestination();
  public A withDestination(io.fabric8.openshift.api.model.operator.v1.LoggingDestination destination);
  public java.lang.Boolean hasDestination();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<A> withNewDestination();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<A> withNewDestinationLike(io.fabric8.openshift.api.model.operator.v1.LoggingDestination item);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<A> editDestination();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<A> editOrNewDestination();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<A> editOrNewDestinationLike(io.fabric8.openshift.api.model.operator.v1.LoggingDestination item);
  public A addToHttpCaptureCookies(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie item);
  public A setToHttpCaptureCookies(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie item);
  public A addToHttpCaptureCookies(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie... items);
  public A addAllToHttpCaptureCookies(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie> items);
  public A removeFromHttpCaptureCookies(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie... items);
  public A removeAllFromHttpCaptureCookies(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie> items);
  public A removeMatchingFromHttpCaptureCookies(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHttpCaptureCookies instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie> getHttpCaptureCookies();
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie> buildHttpCaptureCookies();
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie buildHttpCaptureCooky(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie buildFirstHttpCaptureCooky();
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie buildLastHttpCaptureCooky();
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie buildMatchingHttpCaptureCooky(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder> predicate);
  public java.lang.Boolean hasMatchingHttpCaptureCooky(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder> predicate);
  public A withHttpCaptureCookies(java.util.List<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie> httpCaptureCookies);
  public A withHttpCaptureCookies(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie... httpCaptureCookies);
  public java.lang.Boolean hasHttpCaptureCookies();
  public A addNewHttpCaptureCooky(java.lang.String matchType,java.lang.Integer maxLength,java.lang.String name,java.lang.String namePrefix);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> addNewHttpCaptureCooky();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> addNewHttpCaptureCookyLike(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie item);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> setNewHttpCaptureCookyLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie item);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> editHttpCaptureCooky(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> editFirstHttpCaptureCooky();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> editLastHttpCaptureCooky();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> editMatchingHttpCaptureCooky(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHttpCaptureHeaders instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeaders getHttpCaptureHeaders();
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeaders buildHttpCaptureHeaders();
  public A withHttpCaptureHeaders(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeaders httpCaptureHeaders);
  public java.lang.Boolean hasHttpCaptureHeaders();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<A> withNewHttpCaptureHeaders();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<A> withNewHttpCaptureHeadersLike(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeaders item);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<A> editHttpCaptureHeaders();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<A> editOrNewHttpCaptureHeaders();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<A> editOrNewHttpCaptureHeadersLike(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeaders item);
  public java.lang.String getHttpLogFormat();
  public A withHttpLogFormat(java.lang.String httpLogFormat);
  public java.lang.Boolean hasHttpLogFormat();
  
  /**
   * Method is deprecated. use withHttpLogFormat instead.
   */
  @java.lang.Deprecated
  public A withNewHttpLogFormat(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface DestinationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent<io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<N>>{
    public N and();
    public N endDestination();
    
  }
  public interface HttpCaptureCookiesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<N>>{
    public N and();
    public N endHttpCaptureCooky();
    
  }
  public interface HttpCaptureHeadersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeadersFluent<io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<N>>{
    public N and();
    public N endHttpCaptureHeaders();
    
  }
  
}

==> openshift-model-operator-5.12.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/AccessLoggingFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface AccessLoggingFluent<A extends io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildDestination instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestination getDestination();
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestination buildDestination();
  public A withDestination(io.fabric8.openshift.api.model.operator.v1.LoggingDestination destination);
  public java.lang.Boolean hasDestination();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<A> withNewDestination();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<A> withNewDestinationLike(io.fabric8.openshift.api.model.operator.v1.LoggingDestination item);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<A> editDestination();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<A> editOrNewDestination();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<A> editOrNewDestinationLike(io.fabric8.openshift.api.model.operator.v1.LoggingDestination item);
  public A addToHttpCaptureCookies(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie item);
  public A setToHttpCaptureCookies(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie item);
  public A addToHttpCaptureCookies(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie... items);
  public A addAllToHttpCaptureCookies(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie> items);
  public A removeFromHttpCaptureCookies(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie... items);
  public A removeAllFromHttpCaptureCookies(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie> items);
  public A removeMatchingFromHttpCaptureCookies(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHttpCaptureCookies instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie> getHttpCaptureCookies();
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie> buildHttpCaptureCookies();
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie buildHttpCaptureCooky(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie buildFirstHttpCaptureCooky();
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie buildLastHttpCaptureCooky();
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie buildMatchingHttpCaptureCooky(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder> predicate);
  public java.lang.Boolean hasMatchingHttpCaptureCooky(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder> predicate);
  public A withHttpCaptureCookies(java.util.List<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie> httpCaptureCookies);
  public A withHttpCaptureCookies(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie... httpCaptureCookies);
  public java.lang.Boolean hasHttpCaptureCookies();
  public A addNewHttpCaptureCooky(java.lang.String matchType,java.lang.Integer maxLength,java.lang.String name,java.lang.String namePrefix);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> addNewHttpCaptureCooky();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> addNewHttpCaptureCookyLike(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie item);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> setNewHttpCaptureCookyLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie item);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> editHttpCaptureCooky(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> editFirstHttpCaptureCooky();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> editLastHttpCaptureCooky();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<A> editMatchingHttpCaptureCooky(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHttpCaptureHeaders instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeaders getHttpCaptureHeaders();
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeaders buildHttpCaptureHeaders();
  public A withHttpCaptureHeaders(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeaders httpCaptureHeaders);
  public java.lang.Boolean hasHttpCaptureHeaders();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<A> withNewHttpCaptureHeaders();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<A> withNewHttpCaptureHeadersLike(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeaders item);
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<A> editHttpCaptureHeaders();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<A> editOrNewHttpCaptureHeaders();
  public io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<A> editOrNewHttpCaptureHeadersLike(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeaders item);
  public java.lang.String getHttpLogFormat();
  public A withHttpLogFormat(java.lang.String httpLogFormat);
  public java.lang.Boolean hasHttpLogFormat();
  
  /**
   * Method is deprecated. use withHttpLogFormat instead.
   */
  @java.lang.Deprecated
  public A withNewHttpLogFormat(java.lang.String arg0);
  public java.lang.String getLogEmptyRequests();
  public A withLogEmptyRequests(java.lang.String logEmptyRequests);
  public java.lang.Boolean hasLogEmptyRequests();
  
  /**
   * Method is deprecated. use withLogEmptyRequests instead.
   */
  @java.lang.Deprecated
  public A withNewLogEmptyRequests(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface DestinationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent<io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.DestinationNested<N>>{
    public N and();
    public N endDestination();
    
  }
  public interface HttpCaptureCookiesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureCookiesNested<N>>{
    public N and();
    public N endHttpCaptureCooky();
    
  }
  public interface HttpCaptureHeadersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPHeadersFluent<io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent.HttpCaptureHeadersNested<N>>{
    public N and();
    public N endHttpCaptureHeaders();
    
  }
  
}
